pub struct SyncSdkConfig {
pub api_version: Option<ApiVersion>,
pub config: UploadFile,
pub openapi: Option<UploadFile>,
}Expand description
SyncSdkConfig
Fields
api_version: Option<ApiVersion>Can be either the semantic version or a released type (like latest)
config: UploadFileSDK configuration file in .yaml format
openapi: Option<UploadFile>Use api_version in typical use. If this field is supplied, the configuration sync will match the spec rather than any API that lives in Sideko.