pub struct OrganizationFeatures {Show 15 fields
pub allow_sdk_cli: bool,
pub allow_sdk_csharp: bool,
pub allow_sdk_go: bool,
pub allow_sdk_java: bool,
pub allow_sdk_python: bool,
pub allow_sdk_rust: bool,
pub allow_sdk_tests: bool,
pub allow_sdk_typescript: bool,
pub is_free: bool,
pub max_api_projects: i64,
pub max_doc_projects: i64,
pub max_mock_servers: i64,
pub max_sdk_api_methods: i64,
pub max_service_accounts: i64,
pub max_teammates: i64,
}Expand description
OrganizationFeatures
Fields
allow_sdk_cli: boolIs the organization allowed to generated SDKs for target cli
allow_sdk_csharp: boolIs the organization allowed to generated SDKs for target csharp
allow_sdk_go: boolIs the organization allowed to generated SDKs for target go
allow_sdk_java: boolIs the organization allowed to generated SDKs for target java
allow_sdk_python: boolIs the organization allowed to generated SDKs for target python
allow_sdk_rust: boolIs the organization allowed to generated SDKs for target rust
allow_sdk_tests: boolIs the organization allowed to generated tests with it’s SDKs
allow_sdk_typescript: boolIs the organization allowed to generated SDKs for target typescript
is_free: boolIs the organization using the free version of Sideko
max_api_projects: i64Maximum number of APIs allowed for the organization
max_doc_projects: i64Maximum number of documentation projects allowed for the organization
max_mock_servers: i64Maximum number of mock servers allowed for this organization
max_sdk_api_methods: i64Maximum number of SDK methods allowed in a generation
max_service_accounts: i64Maximum number of service accounts allowed for this organization
max_teammates: i64Maximum number of team members allowed for this organization